@@ -12,9 +12,9 @@ from django.db import transaction
 from django.db.models import F
 from django.db.models import Q
 
-from xj_role.services.role_service import RoleService
 from xj_user.services.user_service import UserService
 from ..models import UserToGroup, RoleUserGroup, UserToRole
+from ..services.role_service import RoleService
 from ..utils.custom_tool import format_params_handle, parse_json, format_list_handle
 from ..utils.j_recur import JRecur
 from ..utils.join_list import JoinList
@@ -161,13 +161,11 @@ class UserGroupService(object):
         # 分组下面用户分页查询
         group_search_params = format_params_handle(
             param_dict=params,
-            filter_filed_list=["group_id", "user_group_id", "user_group_id_list", "user_id", "user_id_list"],
+            filter_filed_list=["group_id|int", "user_group_id|int", "user_group_id_list|list", "user_id|int", "user_id_list|list"],
             alias_dict={"user_group_id_list": "user_group_id__in", "group_id": "user_group_id", "user_id_list": "user_id__in"},
-            is_remove_empty=True
         )
-        # 边界查询,分组(部门)必传
-        # if not group_search_params:
-        #     return None, "参数错误,用户部门必选"
+
+        # 分组用户查询
         user_group_set = UserToGroup.objects.filter(**group_search_params).annotate(
             user_group_value=F("user_group__group_name")
         ).values("user_id", "user_group_value")
@@ -180,8 +178,8 @@ class UserGroupService(object):
             group_user_list = list(paginator.page(paginator.num_pages).object_list)
 
         # 拼接用户信息
-        user_serv, err = UserService.user_list(allow_user_list=[it['user_id'] for it in group_user_list], need_Pagination=False)
-        JoinList.left_join(l_list=group_user_list, r_list=user_serv, l_key="user_id", r_key="user_id")
+        user_serv, err = UserService.user_list(allow_user_list=list(set([it['user_id'] for it in group_user_list])), need_Pagination=False)
+        group_user_list = JoinList(l_list=group_user_list, r_list=user_serv, l_key="user_id", r_key="user_id").join()
 
         # 由于数据迁移导致部门绑定的用户ID,用户表存在该用户的信息了,遍历做出提示
         for i in group_user_list:
@@ -196,21 +194,58 @@ class UserGroupService(object):
         return {"total": total, "page": int(page), "size": int(size), "list": group_user_list}, None
 
     @staticmethod
-    def user_bind_group(user_id: int, group_id: int):
+    def user_bind_group(user_id: int, group_id: int = None, group_value: str = None):
         """
         绑定用户与分组关系，即插入一条用户的分组映射关系
+        :param group_value: 添加角色的value
         :param user_id: 用户ID
         :param group_id: 分组ID
         :return: None,err
         """
+        # 如果存在role_value，则有限使用role_value查询添加的角色
+        if not group_value is None:
+            find_group_id = RoleUserGroup.objects.filter(group=group_value).values("id").first()
+            group_id = find_group_id.get("id", None) if find_group_id else group_id
+
         if not user_id or not group_id:
             return None, "参数错误，user_id, group_id 必传"
+        # 部门校验
+        if not UserToGroup.objects.filter(user_group_id=group_id).first():
+            return None, "该部门不存在"
+
+        # 绑定部门
         try:
-            UserToGroup.objects.get_or_create(
-                {"user_id": user_id, "user_group_id": group_id},
-                user_id=user_id,
-                user_group_id=group_id,
-            )
+            user_group_set = UserToGroup.objects.filter(user_id=user_id, user_group_id=group_id).first()
+            if not user_group_set:
+                UserToGroup.objects.create(user_id=user_id, user_group_id=group_id)
+            return None, None
+        except Exception as e:
+            return None, str(e)
+
+    @staticmethod
+    def user_remove_group(user_id: int, group_id: int = None, group_value: str = None):
+        """
+        绑定用户与分组关系，即插入一条用户的分组映射关系
+        :param group_value: 添加角色的value
+        :param user_id: 用户ID
+        :param group_id: 分组ID
+        :return: None,err
+        """
+
+        # 如果存在role_value，则有限使用role_value查询添加的角色
+        if not group_value is None:
+            find_group_id = RoleUserGroup.objects.filter(group=group_value).values("id").first()
+            group_id = find_group_id.get("id", None) if find_group_id else group_id
+
+        # 参数介绍
+        if not user_id or not group_id:
+            return None, "参数错误，user_id, group_id 必传"
+
+        # 移除部门
+        try:
+            user_group_set = UserToGroup.objects.filter(user_id=user_id, user_group_id=group_id).first()
+            if user_group_set:
+                UserToGroup.objects.filter(user_id=user_id, user_group_id=group_id).delete()
             return None, None
         except Exception as e:
             return None, str(e)
@@ -280,6 +315,7 @@ class UserGroupService(object):
         tree_data, err = UserGroupService.get_user_group_tree(group_id)
         if err:
             return None, err
+        # 角色列表，并建立映射
         role_list, err = RoleService.get_role_list({}, None)
         role_dict = {}
         for role in role_list:
@@ -288,15 +324,22 @@ class UserGroupService(object):
                 role_dict[index] = []
             role_dict[index].append(role)
 
+        # 统一名称字段，角色拼接到部门
         def parse_tree(tree, parent_group_id=None):
             for item in tree:
                 if "children" not in item.keys():
                     item['children'] = []
                 if len(item['children']) > 0:
                     parse_tree(item['children'], item["id"])
+
                 if str(item['id']) in role_dict.keys():
-                    # print("> role_dict:", role_dict[str(item['id'])])
+                    role_list = role_dict[str(item['id'])]
+                    for i in role_list:
+                        i["name"] = i.get("role_name", "")
+                        i["type"] = "role"
                     item['children'].extend(role_dict[str(item['id'])])
+                item["name"] = item.get("group_name", "")
+                item["type"] = "group"
             return tree
 
         return parse_tree(parse_json(tree_data), 0), None
